[![publish](https://github.com/geektype/adhan.py/actions/workflows/publish.yml/badge.svg)](https://github.com/geektype/adhan.py/actions/workflows/publish.yml)

# aladhan.py
A complete python wrapper for the [aladhan API](https://aladhan.com/prayer-times-api). 
